# Copyright (C) 2016-2017
# This file is part of the Hierarchical Data Format query language (HDFql)
# For more information about HDFql, please visit the website http://www.hdfql.com

# $Rev: 143 $



#===========================================================
# The following program provides an example on how to use the HDFql R wrapper. The output of executing it would be similar to this:
#
# HDFql version: 1.5.0
# File in use: example.h5
# Attribute value: 12.400000
# Variable:
# 1
# 2
# 3
# 4
# 5
# 6
# Cursor:
# 1
# 2
# 3
# 4
# 5
# 6
# Dataset size: 24
#
#===========================================================

# load HDFql R wrapper (make sure it can be found by the R interpreter)
source("HDFql.R")

# display HDFql version in use
print(paste("HDFql version:", HDFQL_VERSION))

# create an HDF file named "example.h5" and use (i.e. open) it
hdfql_execute("CREATE FILE example.h5")
hdfql_execute("USE FILE example.h5")

# populate HDFql default cursor with name of the HDF file in use and display it
hdfql_execute("SHOW USE FILE")
hdfql_cursor_first()
print(paste("File in use:", hdfql_cursor_get_char()))

# create an attribute named "example_attribute" of type float with a value of 12.4
hdfql_execute("CREATE ATTRIBUTE example_attribute AS FLOAT DEFAULT 12.4")

# select (i.e. read) attribute "example_attribute" and display its value
hdfql_execute("SELECT FROM example_attribute")
hdfql_cursor_first()
print(paste("Attribute value:", hdfql_cursor_get_float()))

# create a dataset named "example_dataset" of type int of two dimensions (size 3x2)
hdfql_execute("CREATE DATASET example_dataset AS INT(3, 2)")

# create variable "values" and populate it with certain values
values <- array(dim = c(3, 2))
for(x in 1:2)
{
	for(y in 1:3)
	{
		values[y, x] <- as.integer(x * 3 + y - 3)
	}
}

# register variable "values" for subsequent use (by HDFql)
hdfql_variable_register(values)

# insert (i.e. write) content of variable "values" into dataset "example_dataset"
hdfql_execute(paste("INSERT INTO example_dataset VALUES FROM MEMORY", hdfql_variable_get_number(values)))

# unregister variable "values" as it is no longer used/needed (by HDFql)
hdfql_variable_unregister(values)

# populate variable "values" with zeros (i.e. reset variable)
for(x in 1:2)
{
	for(y in 1:3)
	{
		values[y, x] <- as.integer(0)
	}
}

# register variable "values" for subsequent use (by HDFql)
hdfql_variable_register(values)

# select (i.e. read) dataset "example_dataset" into variable "values"
hdfql_execute(paste("SELECT FROM example_dataset INTO MEMORY", hdfql_variable_get_number(values)))

# unregister variable "values" as it is no longer used/needed (by HDFql)
hdfql_variable_unregister(values)

# display content of variable "values"
print("Variable:")
for(x in 1:2)
{
	for(y in 1:3)
	{
		print(values[y, x])
	}
}

# another way to select (i.e. read) dataset "example_dataset" using HDFql default cursor
hdfql_execute("SELECT FROM example_dataset")

# display content of HDFql default cursor
print("Cursor:")
while(hdfql_cursor_next() == HDFQL_SUCCESS)
{
	print(hdfql_cursor_get_int())
}

# create cursor "my_cursor" and use it
my_cursor <- hdfql_cursor()
hdfql_cursor_use(my_cursor)

# populate cursor "my_cursor" with size of dataset "example_dataset" and display it
hdfql_execute("SHOW SIZE example_dataset")
hdfql_cursor_first()
print(paste("Dataset size:", hdfql_cursor_get_int()))

